@@ -12,10 +12,10 @@ from snakypy.zshpower.utils.process import reload_zsh
 
 
 class ResetCommand(Base):
-    def __init__(self, home):
+    def __init__(self, home: str):
         Base.__init__(self, home)
 
-    def run(self, arguments) -> None:
+    def run(self, arguments: dict) -> None:
         checking_init(self.HOME, self.logfile)
         if arguments["--config"]:
             create_toml(config_content, self.config_file, force=True)
