@@ -12,21 +12,24 @@ from snakypy.zshpower.prompt.sections.utils import (
     separator,
     symbol_ssh,
 )
-from snakypy.zshpower.utils.catch import verify_objects
+from snakypy.zshpower.utils.catch import get_key, verify_objects
 
 
-def definitive_version(micro_version_enable, python_version, space_elem):
+def definitive_version(
+    micro_version_enable: bool, python_version: list, space_elem: str
+):
     if not micro_version_enable:
         return f"{'{0[0]}.{0[1]}'.format(python_version)}{space_elem}"
     return f"{'{0[0]}.{0[1]}.{0[2]}'.format(python_version)}{space_elem}"
 
 
 class Python:
-    def __init__(self, config):
+    def __init__(self, config: dict, *args):
 
-        self.config = config
-        self.enable = config["python"]["version"]["enable"]
-        self.files = (
+        self.config: dict = config
+        self.args: tuple = args
+        self.enable: bool = get_key(config, "python", "version", "enable")
+        self.files: tuple = (
             "__pycache__",
             "manage.py",
             "setup.py",
@@ -37,17 +40,19 @@ class Python:
         )
         self.folders = ("__pycache__",)
         self.extensions = (".py",)
-        self.symbol = symbol_ssh(config["python"]["symbol"], "py-")
+        self.symbol = symbol_ssh(get_key(config, "python", "symbol"), "py-")
         self.color = (
-            config["python"]["color"]
-            if config["general"]["color"]["enable"] is True
+            get_key(config, "python", "color")
+            if get_key(config, "general", "color", "enable") is True
             else "negative"
         )
-        self.prefix_color = config["python"]["prefix"]["color"]
-        self.prefix_text = element_spacing(config["python"]["prefix"]["text"])
-        self.micro_version_enable = config["python"]["version"]["micro"]["enable"]
+        self.prefix_color = get_key(config, "python", "prefix", "color")
+        self.prefix_text = element_spacing(get_key(config, "python", "prefix", "text"))
+        self.micro_version_enable: bool = get_key(
+            config, "python", "version", "micro", "enable"
+        )
 
-    def get_version(self, space_elem=" ") -> str:
+    def get_version(self, space_elem: str = " ") -> str:
 
         # Checking if you use Python through pyenv or the system.
         if isdir(join(HOME, ".pyenv")):
@@ -103,24 +108,31 @@ class Python:
 
 
 class Virtualenv:
-    def __init__(self, config):
-        self.config = config
-        self.enable = config["python"]["virtualenv"]["enable"]
-        self.hash_enable = config["python"]["virtualenv"]["poetry"]["hash"]["enable"]
-        self.py_enable = config["python"]["virtualenv"]["poetry"]["py"]["enable"]
-        self.symbol = symbol_ssh(config["python"]["virtualenv"]["symbol"], "")
-        self.involved = config["python"]["virtualenv"]["involved"]
+    def __init__(self, config: dict, *args):
+        self.config: dict = config
+        self.args = args
+        self.enable: bool = get_key(config, "python", "virtualenv", "enable")
+        self.hash_enable: bool = get_key(
+            config, "python", "virtualenv", "poetry", "hash", "enable"
+        )
+        self.py_enable = get_key(
+            config, "python", "virtualenv", "poetry", "py", "enable"
+        )
+        self.symbol = symbol_ssh(get_key(config, "python", "virtualenv", "symbol"), "")
+        self.involved = get_key(config, "python", "virtualenv", "involved")
         self.color = (
-            config["python"]["virtualenv"]["color"]
-            if config["general"]["color"]["enable"] is True
+            get_key(config, "python", "virtualenv", "color")
+            if get_key(config, "general", "color", "enable") is True
             else "negative"
         )
-        self.prefix_color = config["python"]["virtualenv"]["prefix"]["color"]
+        self.prefix_color = get_key(config, "python", "virtualenv", "prefix", "color")
         self.prefix_text = element_spacing(
-            config["python"]["virtualenv"]["prefix"]["text"]
+            get_key(config, "python", "virtualenv", "prefix", "text")
         )
-        self.name_enable = config["python"]["virtualenv"]["name"]["normal"]["enable"]
-        self.name_text = config["python"]["virtualenv"]["name"]["text"]
+        self.name_enable = get_key(
+            config, "python", "virtualenv", "name", "normal", "enable"
+        )
+        self.name_text = get_key(config, "python", "virtualenv", "name", "text")
 
     def get_virtualenv(self) -> str:
         if "VIRTUAL_ENV" in environ:
@@ -141,7 +153,7 @@ class Virtualenv:
             return venv_path.split("/")[-1]
         return ""
 
-    def __str__(self, space_elem=" "):
+    def __str__(self, space_elem: str = " "):
         involved_prefix = ""
         involved_suffix = ""
 
